# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CreateTicketDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "ticket_title": "str",
        "description": "str",
        "ticket_priority": "str",
        "ticket_impact": "str",
        "ticket_status": "str",
        "ticket_type": "str",
        "end_user_id": "int",
        "end_user_first_name": "str",
        "end_user_last_name": "str",
        "end_user_email": "str",
        "technician_contact_id": "int",
    }

    attribute_map = {
        "ticket_title": "TicketTitle",
        "description": "Description",
        "ticket_priority": "TicketPriority",
        "ticket_impact": "TicketImpact",
        "ticket_status": "TicketStatus",
        "ticket_type": "TicketType",
        "end_user_id": "EndUserID",
        "end_user_first_name": "EndUserFirstName",
        "end_user_last_name": "EndUserLastName",
        "end_user_email": "EndUserEmail",
        "technician_contact_id": "TechnicianContactID",
    }

    def __init__(
        self,
        ticket_title=None,
        description=None,
        ticket_priority=None,
        ticket_impact=None,
        ticket_status=None,
        ticket_type=None,
        end_user_id=None,
        end_user_first_name=None,
        end_user_last_name=None,
        end_user_email=None,
        technician_contact_id=None,
        _configuration=None,
    ):  # noqa: E501
        """CreateTicketDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ticket_title = None
        self._description = None
        self._ticket_priority = None
        self._ticket_impact = None
        self._ticket_status = None
        self._ticket_type = None
        self._end_user_id = None
        self._end_user_first_name = None
        self._end_user_last_name = None
        self._end_user_email = None
        self._technician_contact_id = None
        self.discriminator = None

        self.ticket_title = ticket_title
        self.description = description
        if ticket_priority is not None:
            self.ticket_priority = ticket_priority
        if ticket_impact is not None:
            self.ticket_impact = ticket_impact
        if ticket_status is not None:
            self.ticket_status = ticket_status
        if ticket_type is not None:
            self.ticket_type = ticket_type
        if end_user_id is not None:
            self.end_user_id = end_user_id
        if end_user_first_name is not None:
            self.end_user_first_name = end_user_first_name
        if end_user_last_name is not None:
            self.end_user_last_name = end_user_last_name
        if end_user_email is not None:
            self.end_user_email = end_user_email
        if technician_contact_id is not None:
            self.technician_contact_id = technician_contact_id

    @property
    def ticket_title(self):
        """Gets the ticket_title of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_title of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_title

    @ticket_title.setter
    def ticket_title(self, ticket_title):
        """Sets the ticket_title of this CreateTicketDTO.


        :param ticket_title: The ticket_title of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and ticket_title is None:
            raise ValueError("Invalid value for `ticket_title`, must not be `None`")  # noqa: E501

        self._ticket_title = ticket_title

    @property
    def description(self):
        """Gets the description of this CreateTicketDTO.  # noqa: E501


        :return: The description of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateTicketDTO.


        :param description: The description of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def ticket_priority(self):
        """Gets the ticket_priority of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_priority of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_priority

    @ticket_priority.setter
    def ticket_priority(self, ticket_priority):
        """Sets the ticket_priority of this CreateTicketDTO.


        :param ticket_priority: The ticket_priority of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Low", "Medium", "High", "Critical"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_priority not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_priority` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_priority, allowed_values
                )
            )

        self._ticket_priority = ticket_priority

    @property
    def ticket_impact(self):
        """Gets the ticket_impact of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_impact of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_impact

    @ticket_impact.setter
    def ticket_impact(self, ticket_impact):
        """Sets the ticket_impact of this CreateTicketDTO.


        :param ticket_impact: The ticket_impact of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["NoImpact", "SiteDown", "ServerIssue", "Minor", "Major", "Crisis"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_impact not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_impact` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_impact, allowed_values
                )
            )

        self._ticket_impact = ticket_impact

    @property
    def ticket_status(self):
        """Gets the ticket_status of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_status of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_status

    @ticket_status.setter
    def ticket_status(self, ticket_status):
        """Sets the ticket_status of this CreateTicketDTO.


        :param ticket_status: The ticket_status of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._ticket_status = ticket_status

    @property
    def ticket_type(self):
        """Gets the ticket_type of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_type of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, ticket_type):
        """Sets the ticket_type of this CreateTicketDTO.


        :param ticket_type: The ticket_type of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Incident", "Problem", "Request", "Change"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_type` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_type, allowed_values
                )
            )

        self._ticket_type = ticket_type

    @property
    def end_user_id(self):
        """Gets the end_user_id of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_id of this CreateTicketDTO.  # noqa: E501
        :rtype: int
        """
        return self._end_user_id

    @end_user_id.setter
    def end_user_id(self, end_user_id):
        """Sets the end_user_id of this CreateTicketDTO.


        :param end_user_id: The end_user_id of this CreateTicketDTO.  # noqa: E501
        :type: int
        """

        self._end_user_id = end_user_id

    @property
    def end_user_first_name(self):
        """Gets the end_user_first_name of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_first_name of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_first_name

    @end_user_first_name.setter
    def end_user_first_name(self, end_user_first_name):
        """Sets the end_user_first_name of this CreateTicketDTO.


        :param end_user_first_name: The end_user_first_name of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._end_user_first_name = end_user_first_name

    @property
    def end_user_last_name(self):
        """Gets the end_user_last_name of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_last_name of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_last_name

    @end_user_last_name.setter
    def end_user_last_name(self, end_user_last_name):
        """Sets the end_user_last_name of this CreateTicketDTO.


        :param end_user_last_name: The end_user_last_name of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._end_user_last_name = end_user_last_name

    @property
    def end_user_email(self):
        """Gets the end_user_email of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_email of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_email

    @end_user_email.setter
    def end_user_email(self, end_user_email):
        """Sets the end_user_email of this CreateTicketDTO.


        :param end_user_email: The end_user_email of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._end_user_email = end_user_email

    @property
    def technician_contact_id(self):
        """Gets the technician_contact_id of this CreateTicketDTO.  # noqa: E501


        :return: The technician_contact_id of this CreateTicketDTO.  # noqa: E501
        :rtype: int
        """
        return self._technician_contact_id

    @technician_contact_id.setter
    def technician_contact_id(self, technician_contact_id):
        """Sets the technician_contact_id of this CreateTicketDTO.


        :param technician_contact_id: The technician_contact_id of this CreateTicketDTO.  # noqa: E501
        :type: int
        """

        self._technician_contact_id = technician_contact_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateTicketDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTicketDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTicketDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class InvoiceQueryDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "is_adhoc": "bool",
        "invoice_id": "str",
        "invoice_number": "int",
        "invoice_number_as_string": "str",
        "total": "float",
        "subtotal": "float",
        "tax": "float",
        "tax_percentage": "float",
        "invoice_date": "datetime",
        "contract_name": "str",
        "period_start_date": "datetime",
        "period_end_date": "datetime",
        "currency": "str",
        "line_items": "list[InvoiceLineItemQueryDTO]",
        "_from": "ContactDetails",
        "to": "ContactDetails",
    }

    attribute_map = {
        "is_adhoc": "IsAdhoc",
        "invoice_id": "InvoiceId",
        "invoice_number": "InvoiceNumber",
        "invoice_number_as_string": "InvoiceNumberAsString",
        "total": "Total",
        "subtotal": "Subtotal",
        "tax": "Tax",
        "tax_percentage": "TaxPercentage",
        "invoice_date": "InvoiceDate",
        "contract_name": "ContractName",
        "period_start_date": "PeriodStartDate",
        "period_end_date": "PeriodEndDate",
        "currency": "Currency",
        "line_items": "LineItems",
        "_from": "From",
        "to": "To",
    }

    def __init__(
        self,
        is_adhoc=None,
        invoice_id=None,
        invoice_number=None,
        invoice_number_as_string=None,
        total=None,
        subtotal=None,
        tax=None,
        tax_percentage=None,
        invoice_date=None,
        contract_name=None,
        period_start_date=None,
        period_end_date=None,
        currency=None,
        line_items=None,
        _from=None,
        to=None,
        _configuration=None,
    ):  # noqa: E501
        """InvoiceQueryDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._is_adhoc = None
        self._invoice_id = None
        self._invoice_number = None
        self._invoice_number_as_string = None
        self._total = None
        self._subtotal = None
        self._tax = None
        self._tax_percentage = None
        self._invoice_date = None
        self._contract_name = None
        self._period_start_date = None
        self._period_end_date = None
        self._currency = None
        self._line_items = None
        self.__from = None
        self._to = None
        self.discriminator = None

        if is_adhoc is not None:
            self.is_adhoc = is_adhoc
        if invoice_id is not None:
            self.invoice_id = invoice_id
        if invoice_number is not None:
            self.invoice_number = invoice_number
        if invoice_number_as_string is not None:
            self.invoice_number_as_string = invoice_number_as_string
        if total is not None:
            self.total = total
        if subtotal is not None:
            self.subtotal = subtotal
        if tax is not None:
            self.tax = tax
        if tax_percentage is not None:
            self.tax_percentage = tax_percentage
        if invoice_date is not None:
            self.invoice_date = invoice_date
        if contract_name is not None:
            self.contract_name = contract_name
        if period_start_date is not None:
            self.period_start_date = period_start_date
        if period_end_date is not None:
            self.period_end_date = period_end_date
        if currency is not None:
            self.currency = currency
        if line_items is not None:
            self.line_items = line_items
        if _from is not None:
            self._from = _from
        if to is not None:
            self.to = to

    @property
    def is_adhoc(self):
        """Gets the is_adhoc of this InvoiceQueryDTO.  # noqa: E501


        :return: The is_adhoc of this InvoiceQueryDTO.  # noqa: E501
        :rtype: bool
        """
        return self._is_adhoc

    @is_adhoc.setter
    def is_adhoc(self, is_adhoc):
        """Sets the is_adhoc of this InvoiceQueryDTO.


        :param is_adhoc: The is_adhoc of this InvoiceQueryDTO.  # noqa: E501
        :type: bool
        """

        self._is_adhoc = is_adhoc

    @property
    def invoice_id(self):
        """Gets the invoice_id of this InvoiceQueryDTO.  # noqa: E501


        :return: The invoice_id of this InvoiceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """Sets the invoice_id of this InvoiceQueryDTO.


        :param invoice_id: The invoice_id of this InvoiceQueryDTO.  # noqa: E501
        :type: str
        """

        self._invoice_id = invoice_id

    @property
    def invoice_number(self):
        """Gets the invoice_number of this InvoiceQueryDTO.  # noqa: E501


        :return: The invoice_number of this InvoiceQueryDTO.  # noqa: E501
        :rtype: int
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this InvoiceQueryDTO.


        :param invoice_number: The invoice_number of this InvoiceQueryDTO.  # noqa: E501
        :type: int
        """

        self._invoice_number = invoice_number

    @property
    def invoice_number_as_string(self):
        """Gets the invoice_number_as_string of this InvoiceQueryDTO.  # noqa: E501


        :return: The invoice_number_as_string of this InvoiceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number_as_string

    @invoice_number_as_string.setter
    def invoice_number_as_string(self, invoice_number_as_string):
        """Sets the invoice_number_as_string of this InvoiceQueryDTO.


        :param invoice_number_as_string: The invoice_number_as_string of this InvoiceQueryDTO.  # noqa: E501
        :type: str
        """

        self._invoice_number_as_string = invoice_number_as_string

    @property
    def total(self):
        """Gets the total of this InvoiceQueryDTO.  # noqa: E501


        :return: The total of this InvoiceQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this InvoiceQueryDTO.


        :param total: The total of this InvoiceQueryDTO.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def subtotal(self):
        """Gets the subtotal of this InvoiceQueryDTO.  # noqa: E501


        :return: The subtotal of this InvoiceQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._subtotal

    @subtotal.setter
    def subtotal(self, subtotal):
        """Sets the subtotal of this InvoiceQueryDTO.


        :param subtotal: The subtotal of this InvoiceQueryDTO.  # noqa: E501
        :type: float
        """

        self._subtotal = subtotal

    @property
    def tax(self):
        """Gets the tax of this InvoiceQueryDTO.  # noqa: E501


        :return: The tax of this InvoiceQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this InvoiceQueryDTO.


        :param tax: The tax of this InvoiceQueryDTO.  # noqa: E501
        :type: float
        """

        self._tax = tax

    @property
    def tax_percentage(self):
        """Gets the tax_percentage of this InvoiceQueryDTO.  # noqa: E501


        :return: The tax_percentage of this InvoiceQueryDTO.  # noqa: E501
        :rtype: float
        """
        return self._tax_percentage

    @tax_percentage.setter
    def tax_percentage(self, tax_percentage):
        """Sets the tax_percentage of this InvoiceQueryDTO.


        :param tax_percentage: The tax_percentage of this InvoiceQueryDTO.  # noqa: E501
        :type: float
        """

        self._tax_percentage = tax_percentage

    @property
    def invoice_date(self):
        """Gets the invoice_date of this InvoiceQueryDTO.  # noqa: E501


        :return: The invoice_date of this InvoiceQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """Sets the invoice_date of this InvoiceQueryDTO.


        :param invoice_date: The invoice_date of this InvoiceQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._invoice_date = invoice_date

    @property
    def contract_name(self):
        """Gets the contract_name of this InvoiceQueryDTO.  # noqa: E501


        :return: The contract_name of this InvoiceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._contract_name

    @contract_name.setter
    def contract_name(self, contract_name):
        """Sets the contract_name of this InvoiceQueryDTO.


        :param contract_name: The contract_name of this InvoiceQueryDTO.  # noqa: E501
        :type: str
        """

        self._contract_name = contract_name

    @property
    def period_start_date(self):
        """Gets the period_start_date of this InvoiceQueryDTO.  # noqa: E501


        :return: The period_start_date of this InvoiceQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._period_start_date

    @period_start_date.setter
    def period_start_date(self, period_start_date):
        """Sets the period_start_date of this InvoiceQueryDTO.


        :param period_start_date: The period_start_date of this InvoiceQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._period_start_date = period_start_date

    @property
    def period_end_date(self):
        """Gets the period_end_date of this InvoiceQueryDTO.  # noqa: E501


        :return: The period_end_date of this InvoiceQueryDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._period_end_date

    @period_end_date.setter
    def period_end_date(self, period_end_date):
        """Sets the period_end_date of this InvoiceQueryDTO.


        :param period_end_date: The period_end_date of this InvoiceQueryDTO.  # noqa: E501
        :type: datetime
        """

        self._period_end_date = period_end_date

    @property
    def currency(self):
        """Gets the currency of this InvoiceQueryDTO.  # noqa: E501


        :return: The currency of this InvoiceQueryDTO.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InvoiceQueryDTO.


        :param currency: The currency of this InvoiceQueryDTO.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def line_items(self):
        """Gets the line_items of this InvoiceQueryDTO.  # noqa: E501


        :return: The line_items of this InvoiceQueryDTO.  # noqa: E501
        :rtype: list[InvoiceLineItemQueryDTO]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this InvoiceQueryDTO.


        :param line_items: The line_items of this InvoiceQueryDTO.  # noqa: E501
        :type: list[InvoiceLineItemQueryDTO]
        """

        self._line_items = line_items

    @property
    def _from(self):
        """Gets the _from of this InvoiceQueryDTO.  # noqa: E501


        :return: The _from of this InvoiceQueryDTO.  # noqa: E501
        :rtype: ContactDetails
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this InvoiceQueryDTO.


        :param _from: The _from of this InvoiceQueryDTO.  # noqa: E501
        :type: ContactDetails
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this InvoiceQueryDTO.  # noqa: E501


        :return: The to of this InvoiceQueryDTO.  # noqa: E501
        :rtype: ContactDetails
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this InvoiceQueryDTO.


        :param to: The to of this InvoiceQueryDTO.  # noqa: E501
        :type: ContactDetails
        """

        self._to = to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(InvoiceQueryDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvoiceQueryDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InvoiceQueryDTO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atera_client.api_client import ApiClient


class DeviceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def device_create_generic_device(self, request, **kwargs):  # noqa: E501
        """Create Generic device  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_generic_device(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateGenericDTO request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_create_generic_device_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.device_create_generic_device_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def device_create_generic_device_with_http_info(self, request, **kwargs):  # noqa: E501
        """Create Generic device  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_generic_device_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateGenericDTO request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method device_create_generic_device" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if self.api_client.client_side_validation and (
            "request" not in params or params["request"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `request` when calling `device_create_generic_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/genericdevice",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreatedDeviceRes",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_create_http_device(self, request, **kwargs):  # noqa: E501
        """Create HTTP device  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_http_device(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateHttpDTO request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_create_http_device_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.device_create_http_device_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def device_create_http_device_with_http_info(self, request, **kwargs):  # noqa: E501
        """Create HTTP device  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_http_device_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateHttpDTO request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_create_http_device" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if self.api_client.client_side_validation and (
            "request" not in params or params["request"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `request` when calling `device_create_http_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/httpdevice",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreatedDeviceRes",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_create_snmp_device_v1_v2(self, request, **kwargs):  # noqa: E501
        """Create SNMP device V1/V2  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_snmp_device_v1_v2(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSNMPDTOV1V2 request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_create_snmp_device_v1_v2_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.device_create_snmp_device_v1_v2_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def device_create_snmp_device_v1_v2_with_http_info(self, request, **kwargs):  # noqa: E501
        """Create SNMP device V1/V2  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_snmp_device_v1_v2_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSNMPDTOV1V2 request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method device_create_snmp_device_v1_v2" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if self.api_client.client_side_validation and (
            "request" not in params or params["request"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `request` when calling `device_create_snmp_device_v1_v2`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/snmpdevice/v1v2",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreatedDeviceRes",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_create_snmp_device_v3(self, request, **kwargs):  # noqa: E501
        """Create SNMP device V3  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_snmp_device_v3(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSNMPDTOV3 request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_create_snmp_device_v3_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.device_create_snmp_device_v3_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def device_create_snmp_device_v3_with_http_info(self, request, **kwargs):  # noqa: E501
        """Create SNMP device V3  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_snmp_device_v3_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateSNMPDTOV3 request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method device_create_snmp_device_v3" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if self.api_client.client_side_validation and (
            "request" not in params or params["request"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `request` when calling `device_create_snmp_device_v3`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/snmpdevice/v3",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreatedDeviceRes",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_create_tcp_device(self, request, **kwargs):  # noqa: E501
        """Create TCP device  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_tcp_device(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTCPDTO request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_create_tcp_device_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.device_create_tcp_device_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def device_create_tcp_device_with_http_info(self, request, **kwargs):  # noqa: E501
        """Create TCP device  # noqa: E501

        Returns device ID and Device Guid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_create_tcp_device_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateTCPDTO request: Required - new device params (required)
        :return: CreatedDeviceRes
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_create_tcp_device" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'request' is set
        if self.api_client.client_side_validation and (
            "request" not in params or params["request"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `request` when calling `device_create_tcp_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "request" in params:
            body_params = params["request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/tcpdevice",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreatedDeviceRes",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_delete(self, device_id, **kwargs):  # noqa: E501
        """Delete specified Generic device  # noqa: E501

        Deletes a Generic device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_delete_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_delete_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_delete_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Delete specified Generic device  # noqa: E501

        Deletes a Generic device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_delete" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `device_id` when calling `device_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/genericdevice/{deviceId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_delete_http(self, device_id, **kwargs):  # noqa: E501
        """Delete specified HTTP device  # noqa: E501

        Deletes an HTTP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_http(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_delete_http_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_delete_http_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_delete_http_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Delete specified HTTP device  # noqa: E501

        Deletes an HTTP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_http_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_delete_http" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_delete_http`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/httpdevice/{deviceId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_delete_snmp(self, device_id, **kwargs):  # noqa: E501
        """Delete specified SNMP device  # noqa: E501

        Deletes an SNMP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_snmp(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_delete_snmp_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_delete_snmp_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_delete_snmp_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Delete specified SNMP device  # noqa: E501

        Deletes an SNMP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_snmp_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_delete_snmp" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_delete_snmp`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/snmpdevice/{deviceId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_delete_tcp(self, device_id, **kwargs):  # noqa: E501
        """Delete specified TCP device  # noqa: E501

        Deletes a TCP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_tcp(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_delete_tcp_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_delete_tcp_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_delete_tcp_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Delete specified TCP device  # noqa: E501

        Deletes a TCP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_delete_tcp_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: Object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_delete_tcp" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_delete_tcp`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/tcpdevice/{deviceId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="Object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_generic_device(self, device_id, **kwargs):  # noqa: E501
        """Find specified Generic device  # noqa: E501

        Returns a Generic device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_generic_device(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: GenericDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_generic_device_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_get_generic_device_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_get_generic_device_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Find specified Generic device  # noqa: E501

        Returns a Generic device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_generic_device_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: GenericDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_generic_device" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_get_generic_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/genericdevice/{deviceId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="GenericDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_generic_devices(self, **kwargs):  # noqa: E501
        """Find Generic devices  # noqa: E501

        Returns a list of Generic devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_generic_devices(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperGenericDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_generic_devices_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.device_get_generic_devices_with_http_info(**kwargs)  # noqa: E501
            return data

    def device_get_generic_devices_with_http_info(self, **kwargs):  # noqa: E501
        """Find Generic devices  # noqa: E501

        Returns a list of Generic devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_generic_devices_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperGenericDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page", "customer_id", "monitoring_agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_generic_devices" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501
        if "customer_id" in params:
            query_params.append(("customerId", params["customer_id"]))  # noqa: E501
        if "monitoring_agent_id" in params:
            query_params.append(("monitoringAgentId", params["monitoring_agent_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/genericdevices",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperGenericDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_http_device(self, device_id, **kwargs):  # noqa: E501
        """Find specified HTTP device  # noqa: E501

        Returns an HTTP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_http_device(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: HttpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_http_device_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_get_http_device_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_get_http_device_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Find specified HTTP device  # noqa: E501

        Returns an HTTP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_http_device_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: HttpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_http_device" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_get_http_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/httpdevice/{deviceId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="HttpDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_http_devices(self, **kwargs):  # noqa: E501
        """Find HTTP devices  # noqa: E501

        Returns a list of HTTP devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_http_devices(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperHttpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_http_devices_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.device_get_http_devices_with_http_info(**kwargs)  # noqa: E501
            return data

    def device_get_http_devices_with_http_info(self, **kwargs):  # noqa: E501
        """Find HTTP devices  # noqa: E501

        Returns a list of HTTP devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_http_devices_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperHttpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page", "customer_id", "monitoring_agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_http_devices" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501
        if "customer_id" in params:
            query_params.append(("customerId", params["customer_id"]))  # noqa: E501
        if "monitoring_agent_id" in params:
            query_params.append(("monitoringAgentId", params["monitoring_agent_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/httpdevices",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperHttpDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_snmp_device(self, device_id, **kwargs):  # noqa: E501
        """Find specified SNMP device  # noqa: E501

        Returns an SNMP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_snmp_device(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: SNMPDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_snmp_device_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_get_snmp_device_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_get_snmp_device_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Find specified SNMP device  # noqa: E501

        Returns an SNMP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_snmp_device_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: SNMPDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_snmp_device" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_get_snmp_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/snmpdevice/{deviceId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SNMPDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_snmp_devices(self, **kwargs):  # noqa: E501
        """Find SNMP devices  # noqa: E501

        Returns a list of SNMP devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_snmp_devices(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperSNMPDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_snmp_devices_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.device_get_snmp_devices_with_http_info(**kwargs)  # noqa: E501
            return data

    def device_get_snmp_devices_with_http_info(self, **kwargs):  # noqa: E501
        """Find SNMP devices  # noqa: E501

        Returns a list of SNMP devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_snmp_devices_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperSNMPDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page", "customer_id", "monitoring_agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_snmp_devices" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501
        if "customer_id" in params:
            query_params.append(("customerId", params["customer_id"]))  # noqa: E501
        if "monitoring_agent_id" in params:
            query_params.append(("monitoringAgentId", params["monitoring_agent_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/snmpdevices",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperSNMPDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_tcp_device(self, device_id, **kwargs):  # noqa: E501
        """Find specified TCP device  # noqa: E501

        Returns a TCP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_tcp_device(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: TcpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_tcp_device_with_http_info(device_id, **kwargs)  # noqa: E501
        else:
            (data) = self.device_get_tcp_device_with_http_info(device_id, **kwargs)  # noqa: E501
            return data

    def device_get_tcp_device_with_http_info(self, device_id, **kwargs):  # noqa: E501
        """Find specified TCP device  # noqa: E501

        Returns a TCP device. Requires the device ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_tcp_device_with_http_info(device_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int device_id: Required - System Device ID (required)
        :return: TcpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["device_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_tcp_device" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and (
            "device_id" not in params or params["device_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `device_id` when calling `device_get_tcp_device`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "device_id" in params:
            path_params["deviceId"] = params["device_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/tcpdevice/{deviceId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="TcpDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def device_get_tcp_devices(self, **kwargs):  # noqa: E501
        """Find TCP devices  # noqa: E501

        Returns a list of TCP devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_tcp_devices(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperTcpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.device_get_tcp_devices_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.device_get_tcp_devices_with_http_info(**kwargs)  # noqa: E501
            return data

    def device_get_tcp_devices_with_http_info(self, **kwargs):  # noqa: E501
        """Find TCP devices  # noqa: E501

        Returns a list of TCP devices.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.device_get_tcp_devices_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: Optional - Page index (default is 1), based on items per page
        :param int items_in_page: Optional - Number of items per page (default is 20, max is 50)
        :param int customer_id: Optional - Customer ID (default is NULL)
        :param int monitoring_agent_id: Optional - Monitoring Agent ID (default is NULL)
        :return: APIResultWrapperTcpDeviceQueryDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["page", "items_in_page", "customer_id", "monitoring_agent_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s'" " to method device_get_tcp_devices" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "page" in params:
            query_params.append(("page", params["page"]))  # noqa: E501
        if "items_in_page" in params:
            query_params.append(("itemsInPage", params["items_in_page"]))  # noqa: E501
        if "customer_id" in params:
            query_params.append(("customerId", params["customer_id"]))  # noqa: E501
        if "monitoring_agent_id" in params:
            query_params.append(("monitoringAgentId", params["monitoring_agent_id"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "text/json"])  # noqa: E501

        # Authentication setting
        auth_settings = ["api-key"]  # noqa: E501

        return self.api_client.call_api(
            "/api/v3/devices/tcpdevices",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="APIResultWrapperTcpDeviceQueryDTO",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
